@@ -1,15 +1,12 @@
-from abc import abstractmethod
+"""Houses Abstract Kerbrose Credential"""
 
-# internal imports
+from abc import abstractmethod
 from pyrestsdk.credential._abstract_credential import AbstractCredential
 
 
 class AbstractKerbroseCredential(AbstractCredential):
-
-    def __init__(self) -> None:
-        super().__init__()
+    """Abstract Kerbrose Credential Type"""
 
     @abstractmethod
-    def get_principle(self) -> str:
-        """Gets the principle information for authing
-        """
\ No newline at end of file
+    def get_principle(self, /) -> str:
+        """Gets the principle information for authing"""
